#!/usr/bin/env bash

[[ ${BURR_BITBUCKET_LOADED:-} -eq 1 ]] && return

bitbucket_list_repos() {
	bitbucket_repo_list=$(curl -X GET -v -u ${bitbucket_consumer_key}:${bitbucket_consumer_secret} \
	-H "Authorization: Bearer ${bitbucket_consumer_access_token}" \
	-H "Content-Type: application/json" \
	"https://api.bitbucket.org/2.0/repositories/${bitbucket_team_name}")
	echo $bitbucket_repo_list
}

bitbucket_repo_exists() {
	bitbucket_repo_already_exists=$(curl -X GET -v -u ${bitbucket_consumer_key}:${bitbucket_consumer_secret} \
		-H "Authorization: Bearer ${bitbucket_consumer_access_token}" \
		-H "Content-Type: application/json" \
		"https://api.bitbucket.org/2.0/repositories/${bitbucket_team_name}/${1}" |  jq '.')
}

bitbucket_project_key_exists() {
	bitbucket_project_already_exists=$(curl -X GET -v -u ${bitbucket_consumer_key}:${bitbucket_consumer_secret} \
		-H "Authorization: Bearer ${bitbucket_consumer_access_token}" \
		-H "Content-Type: application/json" \
		"https://api.bitbucket.org/2.0/repositories/${bitbucket_team_name}/${1}" |  jq '.')
}

bitbucket_project_name_exists() {
	bitbucket_project_already_exists=$(curl -X GET -v -u ${bitbucket_consumer_key}:${bitbucket_consumer_secret} \
		-H "Authorization: Bearer ${bitbucket_consumer_access_token}" \
		-H "Content-Type: application/json" \
		"https://api.bitbucket.org/2.0/repositories/${bitbucket_team_name}/${1}" |  jq '.')
}

# @TODO What if the project is an existing one which we want to use?
# @TODO What if the project name conflicts with an existing project but we want it to be a new one?
bitbucket_create_project() {
	curl -X POST -v -u ${bitbucket_consumer_key}:${bitbucket_consumer_secret} \
		-H "Authorization: Bearer ${bitbucket_consumer_access_token}" \
		-H "Content-Type: application/json" \
		https://api.bitbucket.org/2.0/teams/${bitbucket_team_name}/projects/ \
		-d '{"description": "'"${bitbucket_project_description}"'", "name": "'"${bitbucket_project_name}"'", "key": "'"${bitbucket_project_key}"'", "is_private": true}'
}

# @TODO What happens if the repo name is a duplicate? It returns null and error is http response 400 BAD REQUEST
bitbucket_create_main_repo() {
	bitbucket_remote_url_main_repo=$(curl -X POST -v -u ${bitbucket_consumer_key}:${bitbucket_consumer_secret} \
		-H "Authorization: Bearer ${bitbucket_consumer_access_token}" \
		-H "Content-Type: application/json" \
		https://api.bitbucket.org/2.0/repositories/${bitbucket_team_name}/${main_repo_name} \
		-d '{"scm": "git", "is_private": true, "fork_policy": "no_public_forks", "project": {"key": "'"${bitbucket_project_key}"'"} }' |  jq --raw-output '.links.clone[1].href')
}

bitbucket_create_main_repo_no_conflict() {
	bitbucket_remote_url_main_repo=$(curl -X POST -v -u ${bitbucket_consumer_key}:${bitbucket_consumer_secret} \
		-H "Authorization: Bearer ${bitbucket_consumer_access_token}" \
		-H "Content-Type: application/json" \
		https://api.bitbucket.org/2.0/repositories/${bitbucket_team_name}/www.${main_repo_name} \
		-d '{"scm": "git", "is_private": true, "fork_policy": "no_public_forks", "project": {"key": "'"${bitbucket_project_key}"'"} }' |  jq --raw-output '.links.clone[1].href')
}

bitbucket_create_theme_repo() {
	#if [ $child_theme ]; then
	#	theme_name_lowercase_hyphen_no_spaces="${theme_name_lowercase_hyphen_no_spaces}-child"
	#fi
	bitbucket_remote_url_theme_repo=$(curl -X POST -v -u ${bitbucket_consumer_key}:${bitbucket_consumer_secret} \
		-H "Authorization: Bearer ${bitbucket_consumer_access_token}" \
		-H "Content-Type: application/json" \
		https://api.bitbucket.org/2.0/repositories/${bitbucket_team_name}/${theme_name_lowercase_hyphen_no_spaces} \
		-d '{"scm": "git", "is_private": true, "fork_policy": "no_public_forks", "project": {"key": "'"${bitbucket_project_key}"'"} }' |  jq --raw-output '.links.clone[1].href')
}

bitbucket_create_mockups_repo() {
	bitbucket_remote_url_mockups_repo=$(curl -X POST -v -u ${bitbucket_consumer_key}:${bitbucket_consumer_secret} \
		-H "Authorization: Bearer ${bitbucket_consumer_access_token}" \
		-H "Content-Type: application/json" \
		https://api.bitbucket.org/2.0/repositories/${bitbucket_team_name}/${main_repo_name}-mockups \
		-d '{"scm": "git", "is_private": true, "fork_policy": "no_public_forks", "project": {"key": "'"${bitbucket_project_key}"'"} }' |  jq --raw-output '.links.clone[1].href')
}

BURR_BITBUCKET_LOADED=1
